fn from_infix(token: &Token) -> Option<(PatOp, Prec)>Expand description
Tries to map the incoming Token to a pattern operator and its following precedence level
fn from_infix(token: &Token) -> Option<(PatOp, Prec)>Tries to map the incoming Token to a pattern operator and its following precedence level